# API Reference

Auto-generated documentation from source docstrings.

- [plot_mesh](mesh.md) — structured mesh plotting
- [plot_contour](contour.md) — filled contour plotting
- [CLI](cli.md) — command-line interface
